@@ -158,7 +158,7 @@ anti_sample <- function(anti_sample_batches,
     out
   })
   
-  out <- Reduce(rbind, unsampled_list)
+  out <- dplyr::bind_rows(unsampled_list)
   
   ## get rid of duplicate rows per sample call
   agg_cols <- gsub("ga:","",dimensions) 
