@@ -3,8 +3,8 @@
   op <- options()
   op.googleAnalyticsR <- list(
     ## default Google project
-    googleAuthR.client_id = "289759286325-da3fr5kq4nl4nkhmhs2uft776kdsggbo.apps.googleusercontent.com",
-    googleAuthR.client_secret = "1mKySbffYRyWevGkjL0LMJYu",
+    googleAuthR.client_id = "289759286325-i5kd45j7qnoc1t8h86611b38icnfk38d.apps.googleusercontent.com",
+    googleAuthR.client_secret = "RnKpRn0ZOrKbwwSPeX4Giujf",
     googleAuthR.webapp.client_id = "289759286325-42j8nmkeq5n9v9eb1kiuj2i97v9oea1f.apps.googleusercontent.com",
     googleAuthR.webapp.client_secret = "0zBtmZ_klTEzXUaTUTP5AkNQ",
     googleAuthR.scopes.selected = c("https://www.googleapis.com/auth/analytics", 
@@ -63,8 +63,6 @@
               "https://www.googleapis.com/auth/analytics.manage.users",
               "https://www.googleapis.com/auth/analytics.user.deletion")
   
-  googleAuthR::gar_attach_auto_auth(needed, 
-                                    environment_var = "GARGLE_EMAIL")
   # for json files
   googleAuthR::gar_attach_auto_auth(needed, 
                                     environment_var = "GA_AUTH_FILE")
